==> jc-1.4.0.tar.gz: java/sql/SQLPermission.h <==
// public final class java.sql.SQLPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class d47e7c5ba7d4bcbc java_sql_SQLPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_sql_SQLPermission_H_
#define _JC_java_sql_SQLPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_sql_SQLPermission$sub_refs	_jc_java_sql_SQLPermission$sub_refs;
typedef struct _jc_java_sql_SQLPermission$sub_nonrefs	_jc_java_sql_SQLPermission$sub_nonrefs;
typedef struct _jc_java_sql_SQLPermission$refs	_jc_java_sql_SQLPermission$refs;
typedef struct _jc_java_sql_SQLPermission$nonrefs	_jc_java_sql_SQLPermission$nonrefs;
typedef struct _jc_java_sql_SQLPermission$object	_jc_java_sql_SQLPermission$object;

typedef const struct _jc_java_sql_SQLPermission$vmethods	_jc_java_sql_SQLPermission$vmethods;
typedef const struct _jc_java_sql_SQLPermission$vtable	_jc_java_sql_SQLPermission$vtable;
typedef const struct _jc_java_sql_SQLPermission$vtype	_jc_java_sql_SQLPermission$vtype;

// Constructors
extern void _jc_java_sql_SQLPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_sql_SQLPermission$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_sql_SQLPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_sql_SQLPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_sql_SQLPermission$vmethods {
};

// Vtable
struct _jc_java_sql_SQLPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_sql_SQLPermission$vmethods	java_sql_SQLPermission;
};

// Vtype
struct _jc_java_sql_SQLPermission$vtype {
	_jc_type			type;
	_jc_java_sql_SQLPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_SQLPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_SQLPermission$refs {
    _jc_java_sql_SQLPermission$sub_refs	java_sql_SQLPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_SQLPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_SQLPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_sql_SQLPermission$sub_nonrefs	java_sql_SQLPermission;
};

// Object instance structure
struct _jc_java_sql_SQLPermission$object {
	_jc_java_sql_SQLPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_SQLPermission$vtype	*vtype;
	_jc_java_sql_SQLPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_SQLPermission$vtype _jc_java_sql_SQLPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_SQLPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_SQLPermission$class_object;

#endif	/* _JC_java_sql_SQLPermission_H_ */

==> jc-1.4.6.tar.gz: java/sql/SQLPermission.h <==
// public final class java.sql.SQLPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class d47e7c5ba7d4bcbc java_sql_SQLPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_sql_SQLPermission_H_
#define _JC_java_sql_SQLPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_sql_SQLPermission$sub_refs	_jc_java_sql_SQLPermission$sub_refs;
typedef struct _jc_java_sql_SQLPermission$sub_nonrefs	_jc_java_sql_SQLPermission$sub_nonrefs;
typedef struct _jc_java_sql_SQLPermission$refs	_jc_java_sql_SQLPermission$refs;
typedef struct _jc_java_sql_SQLPermission$nonrefs	_jc_java_sql_SQLPermission$nonrefs;
typedef struct _jc_java_sql_SQLPermission$object	_jc_java_sql_SQLPermission$object;

typedef const struct _jc_java_sql_SQLPermission$vmethods	_jc_java_sql_SQLPermission$vmethods;
typedef const struct _jc_java_sql_SQLPermission$vtable	_jc_java_sql_SQLPermission$vtable;
typedef const struct _jc_java_sql_SQLPermission$vtype	_jc_java_sql_SQLPermission$vtype;

// Constructors
extern void _jc_java_sql_SQLPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_sql_SQLPermission$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_sql_SQLPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_sql_SQLPermission$vmethods {
};

// Vtable
struct _jc_java_sql_SQLPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_sql_SQLPermission$vmethods	java_sql_SQLPermission;
};

// Vtype
struct _jc_java_sql_SQLPermission$vtype {
	_jc_type			type;
	_jc_java_sql_SQLPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_SQLPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_SQLPermission$refs {
    _jc_java_sql_SQLPermission$sub_refs	java_sql_SQLPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_SQLPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_SQLPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_sql_SQLPermission$sub_nonrefs	java_sql_SQLPermission;
};

// Object instance structure
struct _jc_java_sql_SQLPermission$object {
	_jc_java_sql_SQLPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_SQLPermission$vtype	*vtype;
	_jc_java_sql_SQLPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_SQLPermission$vtype _jc_java_sql_SQLPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_SQLPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_SQLPermission$class_object;

#endif	/* _JC_java_sql_SQLPermission_H_ */
